using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using LIT.UploadBar;

namespace InlineUploadBar
{
	/// <summary>
	/// Summary description for UploadProgressBar.
	/// </summary>
	public class UploadProgressBar : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label lblFileName;
		protected System.Web.UI.WebControls.PlaceHolder plcProgressBar;
		protected System.Web.UI.WebControls.Label lblBytesRead;
		protected System.Web.UI.WebControls.PlaceHolder plcAllFiles;
		protected System.Web.UI.HtmlControls.HtmlInputButton btnMore;
		protected System.Web.UI.WebControls.Label lblDataRate;
		protected System.Web.UI.WebControls.Label lblTimeRemaining;
		protected System.Web.UI.WebControls.Label lblBytesTotal;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			// When the page loads, information must be obtained
			// about the upload. The upload is identified by the
			// variable 'UploadID' passed in on the query string.

			// Obtain the unique ID from the query string.
			string uniqueId;
			if (Request.QueryString["UploadID"] != null)
				uniqueId = Request.QueryString["UploadID"];
			else
			{
				CloseWindow();
				return;
			}

			// Display the pane in the parent
			// document.
			ShowWindow();

			// Variables which will be used to read/display the results
			string
				percentage,
				sourceFileName,
				bytesRead,
				bytesTotal,
				dataRate,
				timeRemaining;
			int
				percentageInt,
				bytesReadInt,
				bytesTotalInt,
				timeRemainingInt;

			double dataRateDouble;

			bool completed;

			string[] fileNames;
			// Obtain the status for this upload
			if (!UploadDetails.GetStatus(uniqueId, out sourceFileName, out bytesReadInt, out bytesTotalInt, out percentageInt, out completed, out fileNames, out timeRemainingInt, out dataRateDouble))
			{
				// Set the values to defaults.
				percentage = "unknown";
				bytesRead = "unknown";
				bytesTotal = "unknown";
				sourceFileName = "unknown";
				timeRemaining = "unknown";
				dataRate = "unknown";
			}
			else
			{
				// Put the integers into the strings
				percentage = percentageInt.ToString();
				bytesRead = bytesReadInt.ToString();
				bytesTotal = bytesTotalInt.ToString();

				if (dataRateDouble > 0)
					dataRate = UploadHelperUtils.FormatBytes((long)dataRateDouble);
				else
					dataRate = "unknown";

				if (timeRemainingInt >= 0)
					timeRemaining = new TimeSpan(0, 0, timeRemainingInt).ToString();
				else
					timeRemaining = "unknown";
			}

			// If the upload is finished, close the window.			
			if (completed)	
			{
				UploadDetails.ClearProgress(uniqueId);
				CloseWindow();
				return;
			}

			// Insert the progress bar. The extra strings are the names of the CSS classes
			// to which the various parts of the progress bar belong. These parts
			// are the part of the bar which isn't filled in, the filled in part,
			// and the bar itself. This allows full control of the progress bar's
			// appearance.
			plcProgressBar.Controls.Add(UploadHelperUtils.BuildProgressBar(percentageInt, "progressBarFillerCell", "progressBarCell", "progressBarTable"));

			// Insert the bytes read
			try
			{
				// Try to display the bytes read as a formatted number
				long bytesReadLong = Int64.Parse(bytesRead);
				lblBytesRead.Text = UploadHelperUtils.FormatBytes(bytesReadLong);
			}
			catch
			{
				// If the bytes read string is not a number, simply display
				// it as is.
				lblBytesRead.Text = "&lt;" + bytesRead + "&gt;";
			}

			// Insert the total bytes
			try
			{
				// Try to display the total bytes as a formatted number
				long bytesTotalLong = Int64.Parse(bytesTotal);
				lblBytesTotal.Text = UploadHelperUtils.FormatBytes(bytesTotalLong);
			}
			catch
			{
				// If the total bytes string is not a number, simply display
				// it as is.
				lblBytesTotal.Text = "&lt;" + bytesTotal + "&gt;";
			}

			// Insert the name of the file currently being uploaded
			lblFileName.Text = "&lt;" + sourceFileName + "&gt;";

			lblDataRate.Text = dataRate;
			lblTimeRemaining.Text = timeRemaining;

			// If the variable 'toggleList' came in on the query string,
			// toggle the list display
			if (Request.QueryString["toggleList"] != null)
				ToggleListDisplay();

			// Show the file list
			ShowFileList(fileNames);

			// Schedule a reload in 1 second.
			ScheduleReload(uniqueId, 1);
		}

		/// <summary>
		/// Registers a script into the page which will cause it to hide itself
		/// </summary>
		private void CloseWindow()
		{
			// Build up the script
			string script = "";
			script += "<script language=\"javascript\">\r\n";
			script += "<!--\r\n";
			// Hide the pane in the parent document
			script += "parent.showProgressPanel(false);\r\n";
			script += "//-->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterClientScriptBlock("close", script);
		}

		/// <summary>
		/// Registers a script into the page which will cause it to hide itself
		/// </summary>
		private void ShowWindow()
		{
			// Build up the script
			string script = "";
			script += "<script language=\"javascript\">\r\n";
			script += "<!--\r\n";
			// Show the pane in the parent document
			script += "parent.showProgressPanel(true);\r\n";
			script += "//-->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterClientScriptBlock("show", script);
		}


		// Schedules a reload of the page
		private void ScheduleReload(string uniqueId, int reloadSeconds)
		{
			// Build the client side script used to schedule a reload
			string script = "";
			script += "<script type=\"text/javascript\"><!--\r\n";
			string path = "UploadProgressBar.aspx?UploadID=" + uniqueId;
			script += "setTimeout(\"document.location.href = '" + path + "' + (toggleList ? '&ToggleList=true' : '');\"," + reloadSeconds * 1000 + ");";
			script += "// -->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterStartupScript("reload", script);
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void ToggleListDisplay()
		{
			// Toggle the display of the detailed list
			string displayList;
			if (Session["displayList"] == null)
				displayList = "false";
			else
				displayList = Session["displayList"].ToString();

			if (displayList == "true")
			{
				Session["displayList"] = "false";
			}
			else
				Session["displayList"] = "true";
		}

		private void ShowFileList(string[] fileNames)
		{
			// If the list of files contains more than 1 file, place the list of
			// files uploaded into the page, minus the last element, as this is the
			// file currently being uploaded.
			btnMore.Visible = false;
			if (fileNames != null && fileNames.Length > 1)
			{
				// This page uses the session to determine if the
				// file list should be inserted into the page.
				object displayList = Session["displayList"];
				btnMore.Value = "More >>";
				if (displayList != null && displayList.ToString() == "true")
				{
				
					HtmlSelect fileList = new HtmlSelect();
					fileList.Size = 5;
					for (int fileCount = 0; fileCount < fileNames.Length - 1; fileCount++)
					{
						fileList.Items.Add(new ListItem(fileNames[fileCount]));
					}
					plcAllFiles.Controls.Add(new LiteralControl("<b>File" + (fileNames.Length <= 2 ? "" : "s") + " uploaded</b><br />"));
					plcAllFiles.Controls.Add(fileList);
					btnMore.Value = "Less <<";
				}

				// Make the "more/less" button visible
				btnMore.Visible = true;
			}
		}
	}
}
