using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using LIT.UploadBar;

namespace StyledUploadBar
{
	public class UploadProgressBar : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label lblFileName;
		protected System.Web.UI.WebControls.PlaceHolder plcProgressBar;
		protected System.Web.UI.WebControls.Label lblBytesRead;
		protected System.Web.UI.WebControls.Label lblBytesTotal;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			// When the page loads, information must be obtained
			// about the upload. The upload is identified by the
			// variable 'UploadID' passed in on the query string.

			// Obtain the unique ID from the query string.
			string uniqueId;
			if (Request.QueryString["UploadID"] != null)
				uniqueId = Request.QueryString["UploadID"];
			else
			{
				CloseWindow();
				return;
			}

			// Variables which will be used to read/display the results
			string
				percentage,
				sourceFileName,
				bytesRead,
				bytesTotal;
			int
				percentageInt,
				bytesReadInt,
				bytesTotalInt,
				timeToCompletion;

			double dataRate;

			bool completed;

			string[] fileNames;
			// Obtain the status for this upload
			if (!UploadDetails.GetStatus(uniqueId, out sourceFileName, out bytesReadInt, out bytesTotalInt, out percentageInt, out completed, out fileNames, out timeToCompletion, out dataRate))
			{
				// Set the values to defaults.
				percentage = "unknown";
				bytesRead = "unknown";
				bytesTotal = "unknown";
				sourceFileName = "unknown";
			}
			else
			{
				// Put the integers into the strings
				percentage = percentageInt.ToString();
				bytesRead = bytesReadInt.ToString();
				bytesTotal = bytesTotalInt.ToString();
			}

			// If the upload is finished, close the window.			
			if (completed)	
			{
				UploadDetails.ClearProgress(uniqueId);
				CloseWindow();
				return;
			}

			// Insert the progress bar. The extra strings are the names of the CSS classes
			// to which the various parts of the progress bar belong. These parts
			// are the part of the bar which isn't filled in, the filled in part,
			// and the bar itself. This allows full control of the progress bar's
			// appearance.
			plcProgressBar.Controls.Add(UploadHelperUtils.BuildProgressBar(percentageInt, "progressBarFillerCell", "progressBarCell", "progressBarTable"));

			// Insert the bytes read
			try
			{
				// Try to display the bytes read as a formatted number
				long bytesReadLong = Int64.Parse(bytesRead);
				lblBytesRead.Text = UploadHelperUtils.FormatBytes(bytesReadLong);
			}
			catch
			{
				// If the bytes read string is not a number, simply display
				// it as is.
				lblBytesRead.Text = "&lt;" + bytesRead + "&gt;";
			}

			// Insert the total bytes
			try
			{
				// Try to display the total bytes as a formatted number
				long bytesTotalLong = Int64.Parse(bytesTotal);
				lblBytesTotal.Text = UploadHelperUtils.FormatBytes(bytesTotalLong);
			}
			catch
			{
				// If the total bytes string is not a number, simply display
				// it as is.
				lblBytesTotal.Text = "&lt;" + bytesTotal + "&gt;";
			}

			// Insert the name of the file currently being uploaded
			lblFileName.Text = "&lt;" + sourceFileName + "&gt;";

			// Schedule a reload in 1 second.
			ScheduleReload(uniqueId, 1);
		}

		/// <summary>
		/// Registers a script into the page which will cause it to close itself
		/// </summary>
		private void CloseWindow()
		{
			// Build up the script
			string script = "";
			script += "<script language=\"javascript\">\r\n";
			script += "<!--\r\n";
			script += "window.close();\r\n";
			script += "//-->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterClientScriptBlock("close", script);
		}

		// Schedules a reload of the page
		private void ScheduleReload(string uniqueId, int reloadSeconds)
		{
			// Build the client side script used to schedule a reload
			string script = "";
			script += "<script type=\"text/javascript\"><!--\r\n";
			string path = "UploadProgressBar.aspx?UploadID=" + uniqueId;
			script += "setTimeout(\"document.location.href = '" + path + "';\"," + reloadSeconds * 1000 + ");";
			script += "// -->\r\n";
			script += "</script>\r\n";

			// Place the script into the page
			RegisterStartupScript("reload", script);
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion
	}
}
